@@ -267,12 +267,14 @@ def qePwContinueSubmit(results, pk, codename='', add_parameters={}, del_paramete
         if 'queue_name' in cluster_options.keys():
             restart_builder.metadata.options.queue_name = cluster_options['queue_name']
     else:
-        restart_builder.metadata.options.resources = slurm_options[computer]['resources'] # in here machine = node
-        restart_builder.metadata.options.max_wallclock_seconds = slurm_options[computer]['max_wallclock_seconds'] # in here machine = node
-        restart_builder.metadata.options.account = slurm_options[computer]['account'] # in here machine = node
-        restart_builder.metadata.options.scheduler_stderr = slurm_options[computer]['scheduler_stderr']
-        restart_builder.metadata.options.scheduler_stdout = slurm_options[computer]['scheduler_stderr']
-        restart_builder.metadata.options.queue_name = slurm_options[computer]['queue_name']
+        restart_builder.metadata.options.update({
+            'resources': slurm_options[computer]['resources'],
+            'max_wallclock_seconds': slurm_options[computer]['max_wallclock_seconds'],
+            'account': slurm_options[computer]['account'],
+            'scheduler_stderr': slurm_options[computer]['scheduler_stderr'],
+            'scheduler_stdout': slurm_options[computer]['scheduler_stdout'],
+            'queue_name': slurm_options[computer]['queue_name']
+        })
 
     # reset metadata
     if len(metadata) > 0:
